@@ -2,10 +2,10 @@
 # Elasticsearch B.V licenses this file to you under the Apache 2.0 License.
 # See the LICENSE file in the project root for more information
 
-package Search::Elasticsearch::Client::7_0::Direct;
-$Search::Elasticsearch::Client::7_0::Direct::VERSION = '7.717';
+package Search::Elasticsearch::Client::8_0::Direct;
+$Search::Elasticsearch::Client::8_0::Direct::VERSION = '8.12';
 use Moo;
-with 'Search::Elasticsearch::Client::7_0::Role::API';
+with 'Search::Elasticsearch::Client::8_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 
 use Search::Elasticsearch::Util qw(parse_params is_compat);
@@ -18,15 +18,18 @@ has 'autoscaling'          => ( is => 'lazy', init_arg => undef );
 has 'cat'                  => ( is => 'lazy', init_arg => undef );
 has 'ccr'                  => ( is => 'lazy', init_arg => undef );
 has 'cluster'              => ( is => 'lazy', init_arg => undef );
+has 'connector'            => ( is => 'lazy', init_arg => undef );
+has 'connector_sync_job'   => ( is => 'lazy', init_arg => undef );
 has 'dangling_indices'     => ( is => 'lazy', init_arg => undef );
-has 'data_frame_transform_deprecated' => ( is => 'lazy', init_arg => undef );
 has 'enrich'               => ( is => 'lazy', init_arg => undef );
 has 'eql'                  => ( is => 'lazy', init_arg => undef );
+has 'esql'                 => ( is => 'lazy', init_arg => undef );
 has 'features'             => ( is => 'lazy', init_arg => undef );
 has 'fleet'                => ( is => 'lazy', init_arg => undef );
 has 'graph'                => ( is => 'lazy', init_arg => undef );
 has 'ilm'                  => ( is => 'lazy', init_arg => undef );
 has 'indices'              => ( is => 'lazy', init_arg => undef );
+has 'inference'            => ( is => 'lazy', init_arg => undef );
 has 'ingest'               => ( is => 'lazy', init_arg => undef );
 has 'license'              => ( is => 'lazy', init_arg => undef );
 has 'logstash'             => ( is => 'lazy', init_arg => undef );
@@ -34,14 +37,19 @@ has 'migration'            => ( is => 'lazy', init_arg => undef );
 has 'ml'                   => ( is => 'lazy', init_arg => undef );
 has 'monitoring'           => ( is => 'lazy', init_arg => undef );
 has 'nodes'                => ( is => 'lazy', init_arg => undef );
+has 'profiling'            => ( is => 'lazy', init_arg => undef );
+has 'query_ruleset'        => ( is => 'lazy', init_arg => undef );
 has 'rollup'               => ( is => 'lazy', init_arg => undef );
 has 'searchable_snapshots' => ( is => 'lazy', init_arg => undef );
+has 'search_application'   => ( is => 'lazy', init_arg => undef );
 has 'security'             => ( is => 'lazy', init_arg => undef );
 has 'shutdown'             => ( is => 'lazy', init_arg => undef );
+has 'simulate'             => ( is => 'lazy', init_arg => undef );
 has 'snapshot'             => ( is => 'lazy', init_arg => undef );
 has 'slm'                  => ( is => 'lazy', init_arg => undef );
 has 'sql'                  => ( is => 'lazy', init_arg => undef );
 has 'ssl'                  => ( is => 'lazy', init_arg => undef );
+has 'synonyms'             => ( is => 'lazy', init_arg => undef );
 has 'tasks'                => ( is => 'lazy', init_arg => undef );
 has 'text_structure'       => ( is => 'lazy', init_arg => undef );
 has 'transform'            => ( is => 'lazy', init_arg => undef );
@@ -92,15 +100,18 @@ sub _build_async_search         { shift->_build_namespace('AsyncSearch') }
 sub _build_cat                  { shift->_build_namespace('Cat') }
 sub _build_ccr                  { shift->_build_namespace('CCR') }
 sub _build_cluster              { shift->_build_namespace('Cluster') }
+sub _build_connector            { shift->_build_namespace('Connector') }
+sub _build_connector_sync_job   { shift->_build_namespace('ConnectorSyncJob') }
 sub _build_dangling_indices     { shift->_build_namespace('DanglingIndices') }
-sub _build_data_frame_transform_deprecated { shift->_build_namespace('DataFrameTransformDeprecated') }
 sub _build_enrich               { shift->_build_namespace('Enrich') }
 sub _build_eql                  { shift->_build_namespace('Eql') }
+sub _build_esql                 { shift->_build_namespace('Esql') }
 sub _build_features             { shift->_build_namespace('Features') }
 sub _build_fleet                { shift->_build_namespace('Fleet') }
 sub _build_graph                { shift->_build_namespace('Graph') }
 sub _build_ilm                  { shift->_build_namespace('ILM') }
 sub _build_indices              { shift->_build_namespace('Indices') }
+sub _build_inference            { shift->_build_namespace('Inference') }
 sub _build_ingest               { shift->_build_namespace('Ingest') }
 sub _build_license              { shift->_build_namespace('License') }
 sub _build_logstash             { shift->_build_namespace('Logstash') }
@@ -108,14 +119,19 @@ sub _build_migration            { shift->_build_namespace('Migration') }
 sub _build_ml                   { shift->_build_namespace('ML') }
 sub _build_monitoring           { shift->_build_namespace('Monitoring') }
 sub _build_nodes                { shift->_build_namespace('Nodes') }
+sub _build_profiling            { shift->_build_namespace('Profiling') }
+sub _build_query_ruleset        { shift->_build_namespace('QueryRuleset') }
 sub _build_rollup               { shift->_build_namespace('Rollup') }
 sub _build_searchable_snapshots { shift->_build_namespace('SearchableSnapshots') }
+sub _build_search_application   { shift->_build_namespace('SearchApplication') }
 sub _build_security             { shift->_build_namespace('Security') }
 sub _build_shutdown             { shift->_build_namespace('Shutdown') }
+sub _build_simulate             { shift->_build_namespace('Simulate') }
 sub _build_snapshot             { shift->_build_namespace('Snapshot') }
 sub _build_slm                  { shift->_build_namespace('Slm') }
 sub _build_sql                  { shift->_build_namespace('SQL') }
 sub _build_ssl                  { shift->_build_namespace('SSL') }
+sub _build_synonyms             { shift->_build_namespace('Synonyms') }
 sub _build_tasks                { shift->_build_namespace('Tasks') }
 sub _build_text_structure       { shift->_build_namespace('TextStructure') }
 sub _build_transform            { shift->_build_namespace('Transform') }
@@ -133,11 +149,11 @@ __PACKAGE__->_install_api('');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::7_0::Direct - Thin client with full support for Elasticsearch 7.x APIs
+Search::Elasticsearch::Client::8_0::Direct - Thin client with full support for Elasticsearch 8.x APIs
 
 =head1 VERSION
 
-version 7.717
+version 8.12
 
 =head1 SYNOPSIS
 
@@ -145,7 +161,7 @@ Create a client:
 
     use Search::Elasticsearch;
     my $e = Search::Elasticsearch->new(
-        client => '7_0::Direct'
+        client => '8_0::Direct'
     );
 
 Index a doc:
@@ -234,11 +250,11 @@ Index lifecycle management requests:
 
 =head1 DESCRIPTION
 
-The L<Search::Elasticsearch::Client::7_0::Direct> class provides the
-Elasticsearch 7.x compatible client returned by:
+The L<Search::Elasticsearch::Client::8_0::Direct> class provides the
+Elasticsearch 8.x compatible client returned by:
 
     $e = Search::Elasticsearch->new(
-        client => "7_0::Direct"  # default
+        client => "8_0::Direct"  # default
     );
 
 It is intended to be as close as possible to the native REST API that
@@ -253,16 +269,20 @@ and the L<cluster|/cluster()>.
 
 =head1 PREVIOUS VERSIONS OF ELASTICSEARCH
 
-This version of the client supports the Elasticsearch 7.0 branch,
+This version of the client supports the Elasticsearch 8.0 branch,
 which is not backwards compatible with earlier branches.
 
-If you need to talk to a version of Elasticsearch before 7.0.0, please
+If you need to talk to a version of Elasticsearch before 8.0.0, please
 install one of the following modules:
 
 =over
 
 =item *
 
+L<Search::Elasticsearch::Client::7_0>
+
+=item *
+
 L<Search::Elasticsearch::Client::6_0>
 
 =item *
@@ -391,12 +411,12 @@ Multiple error codes can be specified with an array:
 =head2 C<bulk_helper_class>
 
 The class to use for the L</bulk_helper()> method. Defaults to
-L<Search::Elasticsearch::Client::7_0::Bulk>.
+L<Search::Elasticsearch::Client::8_0::Bulk>.
 
 =head2 C<scroll_helper_class>
 
 The class to use for the L</scroll_helper()> method. Defaults to
-L<Search::Elasticsearch::Client::7_0::Scroll>.
+L<Search::Elasticsearch::Client::8_0::Scroll>.
 
 =head1 GENERAL METHODS
 
@@ -418,7 +438,7 @@ response, otherwise it throws an error.
 
     $indices_client = $e->indices;
 
-Returns a L<Search::Elasticsearch::Client::7_0::Direct::Indices> object which can be used
+Returns a L<Search::Elasticsearch::Client::8_0::Direct::Indices> object which can be used
 for managing indices, eg creating, deleting indices, managing mapping,
 index settings etc.
 
@@ -426,28 +446,28 @@ index settings etc.
 
     $ingest_client = $e->ingest;
 
-Returns a L<Search::Elasticsearch::Client::7_0::Direct::Ingest> object which can be used
+Returns a L<Search::Elasticsearch::Client::8_0::Direct::Ingest> object which can be used
 for managing ingest pipelines.
 
 =head2 C<cluster()>
 
     $cluster_client = $e->cluster;
 
-Returns a L<Search::Elasticsearch::Client::7_0::Direct::Cluster> object which can be used
+Returns a L<Search::Elasticsearch::Client::8_0::Direct::Cluster> object which can be used
 for managing the cluster, eg cluster-wide settings and cluster health.
 
 =head2 C<nodes()>
 
     $node_client = $e->nodes;
 
-Returns a L<Search::Elasticsearch::Client::7_0::Direct::Nodes> object which can be used
+Returns a L<Search::Elasticsearch::Client::8_0::Direct::Nodes> object which can be used
 to retrieve node info and stats.
 
 =head2 C<snapshot()>
 
     $snapshot_client = $e->snapshot;
 
-Returns a L<Search::Elasticsearch::Client::7_0::Direct::Snapshot> object which
+Returns a L<Search::Elasticsearch::Client::8_0::Direct::Snapshot> object which
 is used for managing backup repositories and creating and restoring
 snapshots.
 
@@ -455,14 +475,14 @@ snapshots.
 
     $tasks_client = $e->tasks;
 
-Returns a L<Search::Elasticsearch::Client::7_0::Direct::Tasks> object which
+Returns a L<Search::Elasticsearch::Client::8_0::Direct::Tasks> object which
 is used for accessing the task management API.
 
 =head2 C<cat()>
 
     $cat_client = $e->cat;
 
-Returns a L<Search::Elasticsearch::Client::7_0::Direct::Cat> object which can be used
+Returns a L<Search::Elasticsearch::Client::8_0::Direct::Cat> object which can be used
 to retrieve simple to read text info for debugging and monitoring an
 Elasticsearch cluster.
 
@@ -470,14 +490,14 @@ Elasticsearch cluster.
 
     $ccr_client = $e->ccr;
 
-Returns a L<Search::Elasticsearch::Client::7_0::Direct::CCR> object which can be used
+Returns a L<Search::Elasticsearch::Client::8_0::Direct::CCR> object which can be used
 to handle cross-cluster replication requests.
 
 =head2 C<ilm()>
 
     $ilm_client = $e->ilm;
 
-Returns a L<Search::Elasticsearch::Client::7_0::Direct::ILM> object which can be used
+Returns a L<Search::Elasticsearch::Client::8_0::Direct::ILM> object which can be used
 to handle index lifecycle management requests.
 
 =head1 DOCUMENT CRUD METHODS
@@ -799,7 +819,7 @@ that need to be made, bulk requests greatly improve performance.
         body    => [ actions ]          # required
     );
 
-See L<Search::Elasticsearch::Client::7_0::Bulk> and L</bulk_helper()> for a helper module that makes
+See L<Search::Elasticsearch::Client::8_0::Bulk> and L</bulk_helper()> for a helper module that makes
 bulk indexing simpler to use.
 
 The C<bulk()> method can perform multiple L</index()>, L</create()>,
@@ -881,7 +901,7 @@ for more information.
     $bulk_helper = $e->bulk_helper( @args );
 
 Returns a new instance of the class specified in the L</bulk_helper_class>,
-which defaults to L<Search::Elasticsearch::Client::7_0::Bulk>.
+which defaults to L<Search::Elasticsearch::Client::8_0::Bulk>.
 
 =head2 C<mget()>
 
@@ -1202,7 +1222,7 @@ C<scroll> parameter, the C<scroll()>
 method allows you to keep pulling more results until the results
 are exhausted.
 
-See L</scroll_helper()> and L<Search::Elasticsearch::Client::7_0::Scroll> for a helper utility
+See L</scroll_helper()> and L<Search::Elasticsearch::Client::8_0::Scroll> for a helper utility
 which makes managing scroll requests much easier.
 
 Query string parameters:
@@ -1232,7 +1252,7 @@ up resources on the server.
     $scroll_helper = $e->scroll_helper( @args );
 
 Returns a new instance of the class specified in the L</scroll_helper_class>,
-which defaults to L<Search::Elasticsearch::Client::7_0::Scroll>.
+which defaults to L<Search::Elasticsearch::Client::8_0::Scroll>.
 
 =head2 C<msearch()>
 
@@ -1689,7 +1709,7 @@ Enrico Zimuel <enrico.zimuel@elastic.co>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2022 by Elasticsearch BV.
+This software is Copyright (c) 2024 by Elasticsearch BV.
 
 This is free software, licensed under:
 
@@ -1699,5 +1719,5 @@ This is free software, licensed under:
 
 __END__
 
-# ABSTRACT: Thin client with full support for Elasticsearch 7.x APIs
+# ABSTRACT: Thin client with full support for Elasticsearch 8.x APIs
 
